@@ -41,12 +41,14 @@ _SERVER_FIELDS = (
     'key_name',
     'metadata',
     'networks',
+    'personality',
     'private_v4',
     'public_v4',
     'public_v6',
     'status',
     'updated',
     'user_id',
+    'tags',
 )
 
 _KEYPAIR_FIELDS = (
@@ -451,7 +453,8 @@ class Normalizer(object):
     def _normalize_server(self, server):
         ret = munch.Munch()
         # Copy incoming server because of shared dicts in unittests
-        server = server.copy()
+        # Wrap the copy in munch so that sub-dicts are properly munched
+        server = munch.Munch(server)
 
         self._remove_novaclient_artifacts(server)
 
@@ -460,18 +463,28 @@ class Normalizer(object):
 
         server['flavor'].pop('links', None)
         ret['flavor'] = server.pop('flavor')
+        # From original_names from sdk
+        server.pop('flavorRef', None)
 
         # OpenStack can return image as a string when you've booted
         # from volume
         if str(server['image']) != server['image']:
             server['image'].pop('links', None)
         ret['image'] = server.pop('image')
+        # From original_names from sdk
+        server.pop('imageRef', None)
+        # From original_names from sdk
+        ret['block_device_mapping'] = server.pop('block_device_mapping_v2', {})
 
         project_id = server.pop('tenant_id', '')
         project_id = server.pop('project_id', project_id)
 
         az = _pop_or_get(
             server, 'OS-EXT-AZ:availability_zone', None, self.strict_mode)
+        # the server resource has this already, but it's missing az info
+        # from the resource.
+        # TODO(mordred) Fix server resource to set az in the location
+        server.pop('location', None)
         ret['location'] = self._get_current_location(
             project_id=project_id, zone=az)
 
@@ -480,10 +493,11 @@ class Normalizer(object):
             server, 'os-extended-volumes:volumes_attached',
             [], self.strict_mode)
 
-        config_drive = server.pop('config_drive', False)
+        config_drive = server.pop(
+            'has_config_drive', server.pop('config_drive', False))
         ret['has_config_drive'] = _to_bool(config_drive)
 
-        host_id = server.pop('hostId', None)
+        host_id = server.pop('hostId', server.pop('host_id', None))
         ret['host_id'] = host_id
 
         ret['progress'] = _pop_int(server, 'progress')
@@ -496,13 +510,23 @@ class Normalizer(object):
                 'OS-EXT-STS:task_state',
                 'OS-EXT-STS:vm_state',
                 'OS-SRV-USG:launched_at',
-                'OS-SRV-USG:terminated_at'):
+                'OS-SRV-USG:terminated_at',
+                'OS-EXT-SRV-ATTR:hypervisor_hostname',
+                'OS-EXT-SRV-ATTR:instance_name',
+                'OS-EXT-SRV-ATTR:user_data',
+                'OS-SCH-HNT:scheduler_hints',
+        ):
             short_key = key.split(':')[1]
             ret[short_key] = _pop_or_get(server, key, None, self.strict_mode)
 
         # Protect against security_groups being None
         ret['security_groups'] = server.pop('security_groups', None) or []
 
+        # NOTE(mnaser): The Nova API returns the creation date in `created`
+        #               however the Shade contract returns `created_at` for
+        #               all resources.
+        ret['created_at'] = server.get('created')
+
         for field in _SERVER_FIELDS:
             ret[field] = server.pop(field, None)
         if not ret['networks']:
@@ -914,6 +938,40 @@ class Normalizer(object):
             ret.append(self._normalize_server_usage(server_usage))
         return ret
 
+    def _normalize_coe_clusters(self, coe_clusters):
+        ret = []
+        for coe_cluster in coe_clusters:
+            ret.append(self._normalize_coe_cluster(coe_cluster))
+        return ret
+
+    def _normalize_coe_cluster(self, coe_cluster):
+        """Normalize Magnum COE cluster."""
+        coe_cluster = coe_cluster.copy()
+
+        # Discard noise
+        coe_cluster.pop('links', None)
+
+        c_id = coe_cluster.pop('uuid')
+
+        ret = munch.Munch(
+            id=c_id,
+            location=self._get_current_location(),
+        )
+
+        for key in (
+                'status',
+                'cluster_template_id',
+                'stack_id',
+                'keypair',
+                'master_count',
+                'create_timeout',
+                'node_count',
+                'name'):
+            ret[key] = coe_cluster.pop(key)
+
+        ret['properties'] = coe_cluster
+        return ret
+
     def _normalize_cluster_templates(self, cluster_templates):
         ret = []
         for cluster_template in cluster_templates:
