@@ -20,6 +20,7 @@ from openstack.orchestration.v1 import stack_files as _stack_files
 from openstack.orchestration.v1 import stack_template as _stack_template
 from openstack.orchestration.v1 import template as _template
 from openstack import proxy
+from openstack import resource
 
 
 class Proxy(proxy.Proxy):
@@ -27,10 +28,8 @@ class Proxy(proxy.Proxy):
     def create_stack(self, preview=False, **attrs):
         """Create a new stack from attributes
 
-        :param bool preview: When ``True``, returns
-            an :class:`~openstack.orchestration.v1.stack.StackPreview` object,
-            otherwise an :class:`~openstack.orchestration.v1.stack.Stack`
-            object.
+        :param bool preview: When ``True``, a preview endpoint will be used to
+            verify the template
             *Default: ``False``*
         :param dict attrs: Keyword arguments which will be used to create
                            a :class:`~openstack.orchestration.v1.stack.Stack`,
@@ -39,8 +38,8 @@ class Proxy(proxy.Proxy):
         :returns: The results of stack creation
         :rtype: :class:`~openstack.orchestration.v1.stack.Stack`
         """
-        res_type = _stack.StackPreview if preview else _stack.Stack
-        return self._create(res_type, **attrs)
+        base_path = None if not preview else '/stacks/preview'
+        return self._create(_stack.Stack, base_path=base_path, **attrs)
 
     def find_stack(self, name_or_id, ignore_missing=True):
         """Find a single stack
@@ -59,7 +58,7 @@ class Proxy(proxy.Proxy):
     def stacks(self, **query):
         """Return a generator of stacks
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of stack objects
@@ -79,12 +78,12 @@ class Proxy(proxy.Proxy):
         """
         return self._get(_stack.Stack, stack)
 
-    def update_stack(self, stack, **attrs):
+    def update_stack(self, stack, preview=False, **attrs):
         """Update a stack
 
         :param stack: The value can be the ID of a stack or a
                :class:`~openstack.orchestration.v1.stack.Stack` instance.
-        :param kwargs \*\*attrs: The attributes to update on the stack
+        :param kwargs attrs: The attributes to update on the stack
                                  represented by ``value``.
 
         :returns: The updated stack
@@ -92,7 +91,8 @@ class Proxy(proxy.Proxy):
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
                  when no resource can be found.
         """
-        return self._update(_stack.Stack, stack, **attrs)
+        res = self._get_resource(_stack.Stack, stack, **attrs)
+        return res.update(self, preview)
 
     def delete_stack(self, stack, ignore_missing=True):
         """Delete a stack
@@ -127,6 +127,16 @@ class Proxy(proxy.Proxy):
 
         stk_obj.check(self)
 
+    def abandon_stack(self, stack):
+        """Abandon a stack's without deleting it's resources
+
+        :param stack: The value can be either the ID of a stack or an instance
+                      of :class:`~openstack.orchestration.v1.stack.Stack`.
+        :returns: ``None``
+        """
+        res = self._get_resource(_stack.Stack, stack)
+        return res.abandon(self)
+
     def get_stack_template(self, stack):
         """Get template used by a stack
 
@@ -191,7 +201,7 @@ class Proxy(proxy.Proxy):
 
         :param stack: This can be a stack object, or the name of a stack
                       for which the resources are to be listed.
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of resource objects if the stack exists and
@@ -360,3 +370,44 @@ class Proxy(proxy.Proxy):
         return tmpl.validate(self, template, environment=environment,
                              template_url=template_url,
                              ignore_errors=ignore_errors)
+
+    def wait_for_status(self, res, status='ACTIVE', failures=None,
+                        interval=2, wait=120):
+        """Wait for a resource to be in a particular status.
+
+        :param res: The resource to wait on to reach the specified status.
+                    The resource must have a ``status`` attribute.
+        :type resource: A :class:`~openstack.resource.Resource` object.
+        :param status: Desired status.
+        :param failures: Statuses that would be interpreted as failures.
+        :type failures: :py:class:`list`
+        :param interval: Number of seconds to wait before to consecutive
+                         checks. Default to 2.
+        :param wait: Maximum number of seconds to wait before the change.
+                     Default to 120.
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+                 to the desired status failed to occur in specified seconds.
+        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
+                 has transited to one of the failure statuses.
+        :raises: :class:`~AttributeError` if the resource does not have a
+                ``status`` attribute.
+        """
+        failures = [] if failures is None else failures
+        return resource.wait_for_status(
+            self, res, status, failures, interval, wait)
+
+    def wait_for_delete(self, res, interval=2, wait=120):
+        """Wait for a resource to be deleted.
+
+        :param res: The resource to wait on to be deleted.
+        :type resource: A :class:`~openstack.resource.Resource` object.
+        :param interval: Number of seconds to wait before to consecutive
+                         checks. Default to 2.
+        :param wait: Maximum number of seconds to wait before the change.
+                     Default to 120.
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+                 to delete failed to occur in the specified seconds.
+        """
+        return resource.wait_for_delete(self, res, interval, wait)
