@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import deprecation
 import mock
 import uuid
 
@@ -21,6 +20,9 @@ from openstack.network.v2 import agent
 from openstack.network.v2 import auto_allocated_topology
 from openstack.network.v2 import availability_zone
 from openstack.network.v2 import extension
+from openstack.network.v2 import firewall_group
+from openstack.network.v2 import firewall_policy
+from openstack.network.v2 import firewall_rule
 from openstack.network.v2 import flavor
 from openstack.network.v2 import floating_ip
 from openstack.network.v2 import health_monitor
@@ -30,6 +32,7 @@ from openstack.network.v2 import metering_label
 from openstack.network.v2 import metering_label_rule
 from openstack.network.v2 import network
 from openstack.network.v2 import network_ip_availability
+from openstack.network.v2 import network_segment_range
 from openstack.network.v2 import pool
 from openstack.network.v2 import pool_member
 from openstack.network.v2 import port
@@ -49,8 +52,8 @@ from openstack.network.v2 import service_provider
 from openstack.network.v2 import subnet
 from openstack.network.v2 import subnet_pool
 from openstack.network.v2 import vpn_service
-from openstack import proxy2 as proxy_base2
-from openstack.tests.unit import test_proxy_base2
+from openstack import proxy as proxy_base
+from openstack.tests.unit import test_proxy_base
 
 
 QOS_POLICY_ID = 'qos-policy-id-' + uuid.uuid4().hex
@@ -60,7 +63,7 @@ AGENT_ID = 'agent-id-' + uuid.uuid4().hex
 ROUTER_ID = 'router-id-' + uuid.uuid4().hex
 
 
-class TestNetworkProxy(test_proxy_base2.TestProxyBase):
+class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
         super(TestNetworkProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
@@ -315,6 +318,15 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def test_network_find(self):
         self.verify_find(self.proxy.find_network, network.Network)
 
+    def test_network_find_with_filter(self):
+        self._verify2('openstack.proxy.Proxy._find',
+                      self.proxy.find_network,
+                      method_args=["net1"],
+                      method_kwargs={"project_id": "1"},
+                      expected_args=[network.Network, "net1"],
+                      expected_kwargs={"project_id": "1",
+                                       "ignore_missing": True})
+
     def test_network_get(self):
         self.verify_get(self.proxy.get_network, network.Network)
 
@@ -397,7 +409,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                            {"pool": "test_id"}, {"pool_id": "test_id"})
 
     def test_pool_member_find(self):
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_pool_member,
                       method_args=["MEMBER", "POOL"],
                       expected_args=[pool_member.PoolMember, "MEMBER"],
@@ -405,7 +417,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                                        "ignore_missing": True})
 
     def test_pool_member_get(self):
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_pool_member,
                       method_args=["MEMBER", "POOL"],
                       expected_args=[pool_member.PoolMember, "MEMBER"],
@@ -417,7 +429,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                          expected_kwargs={"pool_id": "test_id"})
 
     def test_pool_member_update(self):
-        self._verify2("openstack.proxy2.BaseProxy._update",
+        self._verify2("openstack.proxy.Proxy._update",
                       self.proxy.update_pool_member,
                       method_args=["MEMBER", "POOL"],
                       expected_args=[pool_member.PoolMember, "MEMBER"],
@@ -488,7 +500,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_bandwidth_limit_rule_find(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_qos_bandwidth_limit_rule,
                       method_args=['rule_id', policy],
                       expected_args=[
@@ -514,7 +526,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_bandwidth_limit_rule_update(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._update',
+        self._verify2('openstack.proxy.Proxy._update',
                       self.proxy.update_qos_bandwidth_limit_rule,
                       method_args=['rule_id', policy],
                       method_kwargs={'foo': 'bar'},
@@ -547,7 +559,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_dscp_marking_rule_find(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_qos_dscp_marking_rule,
                       method_args=['rule_id', policy],
                       expected_args=[qos_dscp_marking_rule.QoSDSCPMarkingRule,
@@ -572,7 +584,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_dscp_marking_rule_update(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._update',
+        self._verify2('openstack.proxy.Proxy._update',
                       self.proxy.update_qos_dscp_marking_rule,
                       method_args=['rule_id', policy],
                       method_kwargs={'foo': 'bar'},
@@ -605,7 +617,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_minimum_bandwidth_rule_find(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_qos_minimum_bandwidth_rule,
                       method_args=['rule_id', policy],
                       expected_args=[
@@ -631,7 +643,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_minimum_bandwidth_rule_update(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._update',
+        self._verify2('openstack.proxy.Proxy._update',
                       self.proxy.update_qos_minimum_bandwidth_rule,
                       method_args=['rule_id', policy],
                       method_kwargs={'foo': 'bar'},
@@ -686,11 +698,11 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def test_quota_get(self):
         self.verify_get(self.proxy.get_quota, quota.Quota)
 
-    @mock.patch.object(proxy_base2.BaseProxy, "_get_resource")
+    @mock.patch.object(proxy_base.Proxy, "_get_resource")
     def test_quota_get_details(self, mock_get):
         fake_quota = mock.Mock(project_id='PROJECT')
         mock_get.return_value = fake_quota
-        self._verify2("openstack.proxy2.BaseProxy._get",
+        self._verify2("openstack.proxy.Proxy._get",
                       self.proxy.get_quota,
                       method_args=['QUOTA_ID'],
                       method_kwargs={'details': True},
@@ -699,11 +711,11 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                                        'requires_id': False})
         mock_get.assert_called_once_with(quota.Quota, 'QUOTA_ID')
 
-    @mock.patch.object(proxy_base2.BaseProxy, "_get_resource")
+    @mock.patch.object(proxy_base.Proxy, "_get_resource")
     def test_quota_default_get(self, mock_get):
         fake_quota = mock.Mock(project_id='PROJECT')
         mock_get.return_value = fake_quota
-        self._verify2("openstack.proxy2.BaseProxy._get",
+        self._verify2("openstack.proxy.Proxy._get",
                       self.proxy.get_quota_default,
                       method_args=['QUOTA_ID'],
                       expected_args=[quota.QuotaDefault],
@@ -764,7 +776,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def test_router_update(self):
         self.verify_update(self.proxy.update_router, router.Router)
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'add_interface')
     def test_add_interface_to_router_with_port(self, mock_add_interface,
                                                mock_get):
@@ -778,7 +790,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"port_id": "PORT"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'add_interface')
     def test_add_interface_to_router_with_subnet(self, mock_add_interface,
                                                  mock_get):
@@ -792,7 +804,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"subnet_id": "SUBNET"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'remove_interface')
     def test_remove_interface_from_router_with_port(self, mock_remove,
                                                     mock_get):
@@ -806,7 +818,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"port_id": "PORT"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'remove_interface')
     def test_remove_interface_from_router_with_subnet(self, mock_remove,
                                                       mock_get):
@@ -820,7 +832,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"subnet_id": "SUBNET"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'add_gateway')
     def test_add_gateway_to_router(self, mock_add, mock_get):
         x_router = router.Router.new(id="ROUTER_ID")
@@ -833,7 +845,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"foo": "bar"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'remove_gateway')
     def test_remove_gateway_from_router(self, mock_remove, mock_get):
         x_router = router.Router.new(id="ROUTER_ID")
@@ -864,6 +876,122 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
             expected_kwargs={'agent_id': AGENT_ID},
         )
 
+    def test_firewall_group_create_attrs(self):
+        self.verify_create(self.proxy.create_firewall_group,
+                           firewall_group.FirewallGroup)
+
+    def test_firewall_group_delete(self):
+        self.verify_delete(self.proxy.delete_firewall_group,
+                           firewall_group.FirewallGroup, False)
+
+    def test_firewall_group_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_firewall_group,
+                           firewall_group.FirewallGroup, True)
+
+    def test_firewall_group_find(self):
+        self.verify_find(self.proxy.find_firewall_group,
+                         firewall_group.FirewallGroup)
+
+    def test_firewall_group_get(self):
+        self.verify_get(self.proxy.get_firewall_group,
+                        firewall_group.FirewallGroup)
+
+    def test_firewall_groups(self):
+        self.verify_list(self.proxy.firewall_groups,
+                         firewall_group.FirewallGroup,
+                         paginated=False)
+
+    def test_firewall_group_update(self):
+        self.verify_update(self.proxy.update_firewall_group,
+                           firewall_group.FirewallGroup)
+
+    def test_firewall_policy_create_attrs(self):
+        self.verify_create(self.proxy.create_firewall_policy,
+                           firewall_policy.FirewallPolicy)
+
+    def test_firewall_policy_delete(self):
+        self.verify_delete(self.proxy.delete_firewall_policy,
+                           firewall_policy.FirewallPolicy, False)
+
+    def test_firewall_policy_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_firewall_policy,
+                           firewall_policy.FirewallPolicy, True)
+
+    def test_firewall_policy_find(self):
+        self.verify_find(self.proxy.find_firewall_policy,
+                         firewall_policy.FirewallPolicy)
+
+    def test_firewall_policy_get(self):
+        self.verify_get(self.proxy.get_firewall_policy,
+                        firewall_policy.FirewallPolicy)
+
+    def test_firewall_policies(self):
+        self.verify_list(self.proxy.firewall_policies,
+                         firewall_policy.FirewallPolicy,
+                         paginated=False)
+
+    def test_firewall_policy_update(self):
+        self.verify_update(self.proxy.update_firewall_policy,
+                           firewall_policy.FirewallPolicy)
+
+    def test_firewall_rule_create_attrs(self):
+        self.verify_create(self.proxy.create_firewall_rule,
+                           firewall_rule.FirewallRule)
+
+    def test_firewall_rule_delete(self):
+        self.verify_delete(self.proxy.delete_firewall_rule,
+                           firewall_rule.FirewallRule, False)
+
+    def test_firewall_rule_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_firewall_rule,
+                           firewall_rule.FirewallRule, True)
+
+    def test_firewall_rule_find(self):
+        self.verify_find(self.proxy.find_firewall_rule,
+                         firewall_rule.FirewallRule)
+
+    def test_firewall_rule_get(self):
+        self.verify_get(self.proxy.get_firewall_rule,
+                        firewall_rule.FirewallRule)
+
+    def test_firewall_rules(self):
+        self.verify_list(self.proxy.firewall_rules,
+                         firewall_rule.FirewallRule,
+                         paginated=False)
+
+    def test_firewall_rule_update(self):
+        self.verify_update(self.proxy.update_firewall_rule,
+                           firewall_rule.FirewallRule)
+
+    def test_network_segment_range_create_attrs(self):
+        self.verify_create(self.proxy.create_network_segment_range,
+                           network_segment_range.NetworkSegmentRange)
+
+    def test_network_segment_range_delete(self):
+        self.verify_delete(self.proxy.delete_network_segment_range,
+                           network_segment_range.NetworkSegmentRange, False)
+
+    def test_network_segment_range_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_network_segment_range,
+                           network_segment_range.NetworkSegmentRange, True)
+
+    def test_network_segment_range_find(self):
+        self.verify_find(self.proxy.find_network_segment_range,
+                         network_segment_range.NetworkSegmentRange)
+
+    def test_network_segment_range_get(self):
+        self.verify_get(self.proxy.get_network_segment_range,
+                        network_segment_range.NetworkSegmentRange)
+
+    def test_network_segment_ranges(self):
+        self.verify_list(self.proxy.network_segment_ranges,
+                         network_segment_range.NetworkSegmentRange,
+                         paginated=False)
+
+    def test_network_segment_range_update(self):
+        self.verify_update(self.proxy.update_network_segment_range,
+                           network_segment_range.NetworkSegmentRange)
+
     def test_security_group_create_attrs(self):
         self.verify_create(self.proxy.create_security_group,
                            security_group.SecurityGroup)
@@ -893,49 +1021,6 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
         self.verify_update(self.proxy.update_security_group,
                            security_group.SecurityGroup)
 
-    @deprecation.fail_if_not_removed
-    def test_security_group_open_port(self):
-        mock_class = 'openstack.network.v2._proxy.Proxy'
-        mock_method = mock_class + '.create_security_group_rule'
-        expected_result = 'result'
-        sgid = 1
-        port = 2
-        with mock.patch(mock_method) as mocked:
-            mocked.return_value = expected_result
-            actual = self.proxy.security_group_open_port(sgid, port)
-            self.assertEqual(expected_result, actual)
-            expected_args = {
-                'direction': 'ingress',
-                'protocol': 'tcp',
-                'remote_ip_prefix': '0.0.0.0/0',
-                'port_range_max': port,
-                'security_group_id': sgid,
-                'port_range_min': port,
-                'ethertype': 'IPv4',
-            }
-            mocked.assert_called_with(**expected_args)
-
-    @deprecation.fail_if_not_removed
-    def test_security_group_allow_ping(self):
-        mock_class = 'openstack.network.v2._proxy.Proxy'
-        mock_method = mock_class + '.create_security_group_rule'
-        expected_result = 'result'
-        sgid = 1
-        with mock.patch(mock_method) as mocked:
-            mocked.return_value = expected_result
-            actual = self.proxy.security_group_allow_ping(sgid)
-            self.assertEqual(expected_result, actual)
-            expected_args = {
-                'direction': 'ingress',
-                'protocol': 'icmp',
-                'remote_ip_prefix': '0.0.0.0/0',
-                'port_range_max': None,
-                'security_group_id': sgid,
-                'port_range_min': None,
-                'ethertype': 'IPv4',
-            }
-            mocked.assert_called_with(**expected_args)
-
     def test_security_group_rule_create_attrs(self):
         self.verify_create(self.proxy.create_security_group_rule,
                            security_group_rule.SecurityGroupRule)
