@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 import uuid
 
 from openstack.network.v2 import qos_minimum_bandwidth_rule
@@ -23,7 +23,7 @@ EXAMPLE = {
 }
 
 
-class TestQoSMinimumBandwidthRule(testtools.TestCase):
+class TestQoSMinimumBandwidthRule(base.TestCase):
 
     def test_basic(self):
         sot = qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule()
@@ -32,10 +32,9 @@ class TestQoSMinimumBandwidthRule(testtools.TestCase):
         self.assertEqual(
             '/qos/policies/%(qos_policy_id)s/minimum_bandwidth_rules',
             sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
