@@ -23,10 +23,10 @@ from openstack.orchestration.v1 import stack_environment
 from openstack.orchestration.v1 import stack_files
 from openstack.orchestration.v1 import stack_template
 from openstack.orchestration.v1 import template
-from openstack.tests.unit import test_proxy_base2
+from openstack.tests.unit import test_proxy_base
 
 
-class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
+class TestOrchestrationProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
         super(TestOrchestrationProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
@@ -36,7 +36,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
 
     def test_create_stack_preview(self):
         method_kwargs = {"preview": True, "x": 1, "y": 2, "z": 3}
-        self.verify_create(self.proxy.create_stack, stack.StackPreview,
+        self.verify_create(self.proxy.create_stack, stack.Stack,
                            method_kwargs=method_kwargs)
 
     def test_find_stack(self):
@@ -47,9 +47,32 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
 
     def test_get_stack(self):
         self.verify_get(self.proxy.get_stack, stack.Stack)
+        self.verify_get_overrided(
+            self.proxy, stack.Stack,
+            'openstack.orchestration.v1.stack.Stack')
 
     def test_update_stack(self):
-        self.verify_update(self.proxy.update_stack, stack.Stack)
+        self._verify2('openstack.orchestration.v1.stack.Stack.update',
+                      self.proxy.update_stack,
+                      expected_result='result',
+                      method_args=['stack'],
+                      method_kwargs={'preview': False},
+                      expected_args=[self.proxy, False])
+
+    def test_update_stack_preview(self):
+        self._verify2('openstack.orchestration.v1.stack.Stack.update',
+                      self.proxy.update_stack,
+                      expected_result='result',
+                      method_args=['stack'],
+                      method_kwargs={'preview': True},
+                      expected_args=[self.proxy, True])
+
+    def test_abandon_stack(self):
+        self._verify2('openstack.orchestration.v1.stack.Stack.abandon',
+                      self.proxy.abandon_stack,
+                      expected_result='result',
+                      method_args=['stack'],
+                      expected_args=[self.proxy])
 
     def test_delete_stack(self):
         self.verify_delete(self.proxy.delete_stack, stack.Stack, False)
@@ -64,7 +87,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
         res = self.proxy.check_stack(stk)
 
         self.assertIsNone(res)
-        mock_check.assert_called_once_with(self.proxy._session)
+        mock_check.assert_called_once_with(self.proxy)
 
     @mock.patch.object(stack.Stack, 'existing')
     def test_check_stack_with_stack_ID(self, mock_stack):
@@ -75,7 +98,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
 
         self.assertIsNone(res)
         mock_stack.assert_called_once_with(id='FAKE_ID')
-        stk.check.assert_called_once_with(self.proxy._session)
+        stk.check.assert_called_once_with(self.proxy)
 
     @mock.patch.object(stack.Stack, 'find')
     def test_get_stack_environment_with_stack_identity(self, mock_find):
@@ -84,7 +107,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
         stk = stack.Stack(id=stack_id, name=stack_name)
         mock_find.return_value = stk
 
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_stack_environment,
                       method_args=['IDENTITY'],
                       expected_args=[stack_environment.StackEnvironment],
@@ -99,7 +122,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
         stack_name = 'test_stack'
         stk = stack.Stack(id=stack_id, name=stack_name)
 
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_stack_environment,
                       method_args=[stk],
                       expected_args=[stack_environment.StackEnvironment],
@@ -107,33 +130,33 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
                                        'stack_name': stack_name,
                                        'stack_id': stack_id})
 
-    @mock.patch.object(stack_files.StackFiles, 'get')
+    @mock.patch.object(stack_files.StackFiles, 'fetch')
     @mock.patch.object(stack.Stack, 'find')
-    def test_get_stack_files_with_stack_identity(self, mock_find, mock_get):
+    def test_get_stack_files_with_stack_identity(self, mock_find, mock_fetch):
         stack_id = '1234'
         stack_name = 'test_stack'
         stk = stack.Stack(id=stack_id, name=stack_name)
         mock_find.return_value = stk
-        mock_get.return_value = {'file': 'content'}
+        mock_fetch.return_value = {'file': 'content'}
 
         res = self.proxy.get_stack_files('IDENTITY')
 
         self.assertEqual({'file': 'content'}, res)
         mock_find.assert_called_once_with(mock.ANY, 'IDENTITY',
                                           ignore_missing=False)
-        mock_get.assert_called_once_with(self.proxy._session)
+        mock_fetch.assert_called_once_with(self.proxy)
 
-    @mock.patch.object(stack_files.StackFiles, 'get')
-    def test_get_stack_files_with_stack_object(self, mock_get):
+    @mock.patch.object(stack_files.StackFiles, 'fetch')
+    def test_get_stack_files_with_stack_object(self, mock_fetch):
         stack_id = '1234'
         stack_name = 'test_stack'
         stk = stack.Stack(id=stack_id, name=stack_name)
-        mock_get.return_value = {'file': 'content'}
+        mock_fetch.return_value = {'file': 'content'}
 
         res = self.proxy.get_stack_files(stk)
 
         self.assertEqual({'file': 'content'}, res)
-        mock_get.assert_called_once_with(self.proxy._session)
+        mock_fetch.assert_called_once_with(self.proxy)
 
     @mock.patch.object(stack.Stack, 'find')
     def test_get_stack_template_with_stack_identity(self, mock_find):
@@ -142,7 +165,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
         stk = stack.Stack(id=stack_id, name=stack_name)
         mock_find.return_value = stk
 
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_stack_template,
                       method_args=['IDENTITY'],
                       expected_args=[stack_template.StackTemplate],
@@ -157,7 +180,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
         stack_name = 'test_stack'
         stk = stack.Stack(id=stack_id, name=stack_name)
 
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_stack_template,
                       method_args=[stk],
                       expected_args=[stack_template.StackTemplate],
@@ -202,8 +225,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
 
         ex = self.assertRaises(exceptions.ResourceNotFound,
                                self.proxy.resources, stack_name)
-        self.assertEqual('ResourceNotFound: No stack found for test_stack',
-                         six.text_type(ex))
+        self.assertEqual('No stack found for test_stack', six.text_type(ex))
 
     def test_create_software_config(self):
         self.verify_create(self.proxy.create_software_config,
@@ -254,7 +276,7 @@ class TestOrchestrationProxy(test_proxy_base2.TestProxyBase):
         res = self.proxy.validate_template(tmpl, env, tmpl_url, ignore_errors)
 
         mock_validate.assert_called_once_with(
-            self.proxy._session, tmpl, environment=env, template_url=tmpl_url,
+            self.proxy, tmpl, environment=env, template_url=tmpl_url,
             ignore_errors=ignore_errors)
         self.assertEqual(mock_validate.return_value, res)
 
